pub struct SessionBuilder { /* private fields */ }Expand description
Builder for configuring a SessionContext with Lance namespaces.
Implementations
Sourceimpl SessionBuilder
impl SessionBuilder
Sourcepub fn with_root(self, ns: NamespaceLevel) -> Self
pub fn with_root(self, ns: NamespaceLevel) -> Self
Attach a root LanceNamespace that is exposed as a dynamic
catalog list via LanceCatalogProviderList.
Sourcepub fn add_catalog(self, name: &str, ns: NamespaceLevel) -> Self
pub fn add_catalog(self, name: &str, ns: NamespaceLevel) -> Self
Register an additional catalog backed by the given namespace.
The catalog is identified by name and can later be combined
with schemas via SessionBuilder::add_schema using the same
namespace.
Sourcepub fn with_config(self, config: SessionConfig) -> Self
pub fn with_config(self, config: SessionConfig) -> Self
Provide an explicit SessionConfig for the underlying
SessionContext.
Sourcepub fn with_default_catalog(
self,
name: &str,
catalog_provider: Option<Arc<dyn CatalogProvider>>,
) -> Self
pub fn with_default_catalog( self, name: &str, catalog_provider: Option<Arc<dyn CatalogProvider>>, ) -> Self
Override the default catalog name used by the session.
Sourcepub fn with_default_schema(
self,
name: &str,
schema_provider: Option<Arc<dyn SchemaProvider>>,
) -> Self
pub fn with_default_schema( self, name: &str, schema_provider: Option<Arc<dyn SchemaProvider>>, ) -> Self
Override the default schema name used by the session.
Sourcepub async fn build(self) -> Result<SessionContext>
pub async fn build(self) -> Result<SessionContext>
Build a SessionContext with all configured namespaces.